@@ -1,5 +1,5 @@
 package App::JobLog::Command::resume;
-$App::JobLog::Command::resume::VERSION = '1.039';
+$App::JobLog::Command::resume::VERSION = '1.040';
 # ABSTRACT: resume last closed task
 
 use App::JobLog -command;
@@ -15,6 +15,7 @@ sub execute {
    my %mustnt = map { $_ => 1 } @{ $opt->without || [] };
    my $test   = sub {
       my $event = shift;
+      return if $event->is_note;
       my @tags  = @{ $event->tags };
       my %tags  = map { $_ => 1 } @tags;
       my $good  = 1;
@@ -64,7 +65,6 @@ sub execute {
    my ( $i, $count, $e ) = ( $log->reverse_iterator, 0 );
    while ( $e = $i->() ) {
       $count++;
-      next unless $e->isa('App::JobLog::Log::Event');
       last if $test->($e);
    }
 
@@ -125,7 +125,7 @@ App::JobLog::Command::resume - resume last closed task
 
 =head1 VERSION
 
-version 1.039
+version 1.040
 
 =head1 SYNOPSIS
 
