@@ -1,5 +1,5 @@
 package App::JobLog::Log::Note;
-$App::JobLog::Log::Note::VERSION = '1.039';
+$App::JobLog::Log::Note::VERSION = '1.040';
 # ABSTRACT: timestamped annotation in log
 
 
@@ -95,6 +95,11 @@ sub intersects {
 }
 
 
+sub is_note {
+  shift->{log}->is_note
+}
+
+
 sub is_open { 0 }
 
 1;
@@ -111,7 +116,7 @@ App::JobLog::Log::Note - timestamped annotation in log
 
 =head1 VERSION
 
-version 1.039
+version 1.040
 
 =head1 DESCRIPTION
 
@@ -175,6 +180,10 @@ event summarization.
 
 Whether this note overlaps the given period.
 
+=head2 is_note
+
+Whether this "note" (events are a subclass of note) is just a note.
+
 =head2 is_open
 
 Returns false: notes have no duration so they cannot be open.
